==> opensaf-5.17.07.tar.gz: opensaf-5.17.07/src/imm/apitest/management/test_saImmOmSearchFinalize.c <==
/*      -*- OpenSAF  -*-
 *
 * (C) Copyright 2008 The OpenSAF Foundation
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. This file and program are licensed
 * under the GNU Lesser General Public License Version 2.1, February 1999.
 * The complete license can be accessed from the following location:
 * http://opensource.org/licenses/lgpl-license.php
 * See the Copying file included with the OpenSAF distribution for full
 * licensing terms.
 *
 * Author(s): Ericsson AB
 *
 */

#include "imm/apitest/immtest.h"

void saImmOmSearchFinalize_01(void)
{
	SaImmSearchHandleT searchHandle;

	safassert(saImmOmInitialize(&immOmHandle, &immOmCallbacks, &immVersion),
		  SA_AIS_OK);
	safassert(saImmOmSearchInitialize_2(immOmHandle, NULL, SA_IMM_SUBTREE,
					    SA_IMM_SEARCH_ONE_ATTR |
						SA_IMM_SEARCH_GET_NO_ATTR,
					    NULL, NULL, &searchHandle),
		  SA_AIS_OK);
	rc = saImmOmSearchFinalize(searchHandle);
	test_validate(rc, SA_AIS_OK);
	safassert(saImmOmFinalize(immOmHandle), SA_AIS_OK);
}

void saImmOmSearchFinalize_02(void)
{
	SaImmSearchHandleT searchHandle;

	safassert(saImmOmInitialize(&immOmHandle, &immOmCallbacks, &immVersion),
		  SA_AIS_OK);
	safassert(saImmOmSearchInitialize_2(immOmHandle, NULL, SA_IMM_SUBTREE,
					    SA_IMM_SEARCH_ONE_ATTR |
						SA_IMM_SEARCH_GET_NO_ATTR,
					    NULL, NULL, &searchHandle),
		  SA_AIS_OK);
	rc = saImmOmSearchFinalize(-1);
	test_validate(rc, SA_AIS_ERR_BAD_HANDLE);
	safassert(saImmOmFinalize(immOmHandle), SA_AIS_OK);
}

==> opensaf-5.19.07.tar.gz: opensaf-5.19.07/src/imm/apitest/management/test_saImmOmSearchFinalize.c <==
/*      -*- OpenSAF  -*-
 *
 * (C) Copyright 2008 The OpenSAF Foundation
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. This file and program are licensed
 * under the GNU Lesser General Public License Version 2.1, February 1999.
 * The complete license can be accessed from the following location:
 * http://opensource.org/licenses/lgpl-license.php
 * See the Copying file included with the OpenSAF distribution for full
 * licensing terms.
 *
 * Author(s): Ericsson AB
 *
 */

#include "imm/apitest/immtest.h"

void saImmOmSearchFinalize_01(void)
{
	SaImmSearchHandleT searchHandle;

	safassert(immutil_saImmOmInitialize(&immOmHandle, &immOmCallbacks, &immVersion),
		  SA_AIS_OK);
	safassert(immutil_saImmOmSearchInitialize_2(immOmHandle, NULL, SA_IMM_SUBTREE,
					    SA_IMM_SEARCH_ONE_ATTR |
						SA_IMM_SEARCH_GET_NO_ATTR,
					    NULL, NULL, &searchHandle),
		  SA_AIS_OK);
	rc = immutil_saImmOmSearchFinalize(searchHandle);
	test_validate(rc, SA_AIS_OK);
	safassert(immutil_saImmOmFinalize(immOmHandle), SA_AIS_OK);
}

void saImmOmSearchFinalize_02(void)
{
	SaImmSearchHandleT searchHandle;

	safassert(immutil_saImmOmInitialize(&immOmHandle, &immOmCallbacks, &immVersion),
		  SA_AIS_OK);
	safassert(immutil_saImmOmSearchInitialize_2(immOmHandle, NULL, SA_IMM_SUBTREE,
					    SA_IMM_SEARCH_ONE_ATTR |
						SA_IMM_SEARCH_GET_NO_ATTR,
					    NULL, NULL, &searchHandle),
		  SA_AIS_OK);
	rc = immutil_saImmOmSearchFinalize(-1);
	test_validate(rc, SA_AIS_ERR_BAD_HANDLE);
	safassert(immutil_saImmOmFinalize(immOmHandle), SA_AIS_OK);
}
